DeviceInputDialog class

Inheritance

Constructors

DeviceInputDialog({Key? key, required String wifiNameValue, required String password, required dynamic callback(String wifiName, String password)})

Properties

alignment → AlignmentGeometry?
How to align the Dialog.
finalinherited
backgroundColor → Color?
The background color of the surface of this Dialog.
finalinherited
callback ↔ dynamic Function(String wifiName, String password)
getter/setter pair
child → Widget?
The widget below this widget in the tree.
finalinherited
clipBehavior → Clip?
Controls how the contents of the dialog are clipped (or not) to the given shape.
finalinherited
constraints → BoxConstraints?
Constrains the size of the dialog.
finalinherited
elevation → double?
The z-coordinate of this Dialog.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
insetAnimationCurve → Curve
The curve to use for the animation shown when the system keyboard intrudes into the space that the dialog is placed in.
finalinherited
insetAnimationDuration → Duration
The duration of the animation to show when the system keyboard intrudes into the space that the dialog is placed in.
finalinherited
insetPadding → EdgeInsets?
The amount of padding added to MediaQueryData.viewInsets on the outside of the dialog. This defines the minimum space between the screen's edges and the dialog.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
password ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsRole → SemanticsRole
The role this dialog represent in assist technologies.
finalinherited
shadowColor → Color?
The color used to paint a drop shadow under the dialog's Material, which reflects the dialog's elevation.
finalinherited
shape → ShapeBorder?
The shape of this dialog's border.
finalinherited
surfaceTintColor → Color?
The color used as a surface tint overlay on the dialog's background color, which reflects the dialog's elevation.
finalinherited
wifiNameValue ↔ String
getter/setter pair

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited