Height class

Constructors

Height({String? mode, num? adjust, num? offset, bool? available, num? lowQuota, num? deltaDist, num? highQuota, String? ponumDist, bool? returnRectangle, bool? startMarkingLine, num? heightDesignValue})
Height.fromJson(Map<String, dynamic> json)

Properties

adjust ↔ num?
getter/setter pair
available ↔ bool?
getter/setter pair
deltaDist ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heightDesignValue ↔ num?
getter/setter pair
highQuota ↔ num?
getter/setter pair
lowQuota ↔ num?
getter/setter pair
mode ↔ String?
getter/setter pair
offset ↔ num?
getter/setter pair
ponumDist ↔ String?
getter/setter pair
returnRectangle ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startMarkingLine ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited