WireboxHeight class

Constructors

WireboxHeight({num? quota, num? adjust, bool? available, String? heightBy, num? groupDelta})
WireboxHeight.fromJson(Map<String, dynamic> json)

Properties

adjust ↔ num?
getter/setter pair
available ↔ bool?
getter/setter pair
groupDelta ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heightBy ↔ String?
getter/setter pair
quota ↔ num?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited